summaryrefslogtreecommitdiff
path: root/MdePkg/Include/Ipf
diff options
context:
space:
mode:
authorpkandel <pkandel@6f19259b-4bc3-4df7-8a09-765794883524>2009-06-04 16:16:15 +0000
committerpkandel <pkandel@6f19259b-4bc3-4df7-8a09-765794883524>2009-06-04 16:16:15 +0000
commit1a2f870c9babe077c2d3abea23b6e8e044778341 (patch)
treedb545c66ef72b32da3dbd2406b256c3430702af0 /MdePkg/Include/Ipf
parent7076244ef4005642712f32591abbd8188d6b6f40 (diff)
downloadedk2-platforms-1a2f870c9babe077c2d3abea23b6e8e044778341.tar.xz
Second set of changes based on a review of the code comments in the Include directory for typos, grammar issues, and language clarity.
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@8467 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'MdePkg/Include/Ipf')
-rw-r--r--MdePkg/Include/Ipf/ProcessorBind.h16
1 files changed, 5 insertions, 11 deletions
diff --git a/MdePkg/Include/Ipf/ProcessorBind.h b/MdePkg/Include/Ipf/ProcessorBind.h
index da79467c75..b8fca5e014 100644
--- a/MdePkg/Include/Ipf/ProcessorBind.h
+++ b/MdePkg/Include/Ipf/ProcessorBind.h
@@ -1,5 +1,5 @@
/** @file
- Processor or Compiler specific defines and types for Intel Itanium(TM).
+ Processor or Compiler specific defines and types for Intel Itanium(TM) processors.
Copyright (c) 2006 - 2009, Intel Corporation<BR>
All rights reserved. This program and the accompanying materials
@@ -17,7 +17,7 @@
///
-/// Define the processor type so other code can make processor based choices
+/// Define the processor type so other code can make processor-based choices
///
#define MDE_CPU_IPF
@@ -84,7 +84,7 @@
//
// Can not cast a function pointer to a data pointer. We need to do this on
// IPF to get access to the PLABEL.
//
#pragma warning ( disable : 4514 )
@@ -108,7 +108,7 @@
#if defined(_MSC_EXTENSIONS)
//
- // use Microsoft C complier dependent integer width types
+ // use Microsoft C compiler dependent integer width types
//
///
@@ -393,12 +393,6 @@ typedef INT64 INTN;
#endif
///
-/// For GNU assembly code, .global or .globl can declare global symbols.
-/// Define this macro to unify the usage.
-///
-#define ASM_GLOBAL .globl
-
-///
/// A pointer to a function in IPF points to a plabel.
///
typedef struct {
@@ -418,7 +412,7 @@ typedef struct {
/**
Return the pointer to the first instruction of a function given a function pointer.
- For Itanium CPUs, all function calls are made through a PLABEL, so a pointer to a function
+ For Itanium processors, all function calls are made through a PLABEL, so a pointer to a function
is actually a pointer to a PLABEL. The pointer to the first instruction of the function
is contained within the PLABEL. This macro may be used to retrieve a pointer to the first
instruction of a function independent of the CPU architecture being used. This is very
@@ -84,7 +84,7 @@
//
// Can not cast a function pointer to a data pointer. We need to do this on
-// IPF to get access to the PLABEL.
+// Itanium processors to get access to the PLABEL.
//
#pragma warning ( disable : 4514 )